(changelog-target)=
# Changelog

The changelog format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

This project uses [Semantic Versioning](https://semver.org/) - MAJOR.MINOR.PATCH

```{towncrier-draft-entries}
```

```{include} ../CHANGELOG.md
:start-after: '# Changelog'
```
